@@ -73,7 +73,7 @@ def tskr():
 	argv_ls = sys.argv
 	# 存在しない場合にpath_fileを生成する
 	path_file = "./file_pool_path.txt"
-	fileinit(path_file, overwrite = False)
+	fileinit(rel2abs(path_file), overwrite = False)
 	### pool_path書き換えモード
 	if len(argv_ls) == 2 and argv_ls[1] == "--poolpath":
 		with open(rel2abs(path_file), "w", encoding = "utf-8") as f:
